##
##  librist.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         librist
Summary:      Reliable Internet Stream Transport
URL:          https://code.videolan.org/rist/librist/
Vendor:       VideoLAN
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      0.2.7
Release:      20220723

#   list of sources
Source0:      https://code.videolan.org/rist/librist/-/archive/v%{version}/librist-v%{version}.tar.gz
Patch0:       librist.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, pkgconfig, meson, ninja
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Reliable Internet Stream Transport (RIST) is a new Specification
    for multi-vendor interoperable professional video delivery over the
    Internet. LibRIST is a C reference implementation for RIST.

%track
    prog librist = {
        version   = %{version}
        url       = https://code.videolan.org/rist/librist/-/releases
        regex     = librist-v(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n librist-v%{version}
    %patch -p0

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O} -Wno-deprecated-declarations" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    meson build \
        --prefix %{l_prefix} \
        --buildtype release \
        --default-library static \
        --backend ninja \
        -Dbuiltin_cjson=true \
        -Dbuiltin_mbedtls=true \
        -Duse_mbedtls=true

    #   build package
    ninja -C build

%install
    #   install package
    DESTDIR=$RPM_BUILD_ROOT ninja -C build install

    #   strip down and post-adjust installation
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    mv  $RPM_BUILD_ROOT%{l_prefix}/libdata/pkgconfig \
        $RPM_BUILD_ROOT%{l_prefix}/lib
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/libdata

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

